Learn R Programming

SVDMx (version 0.1.0)

SVDMx-package: SVDMx: child or child/adult mortality-indexed mortality schedules

Description

Implementation of the SVD-Comp mortality model. The qx() function generates full age schedules of mortality in single year or 5-year age groups from either child mortality, 5q0, alone or both child, 5q0, and adult mortality, 45q15. For a full description of the model see arXiv preprint Clark (2016) tools:::Rd_expr_doi("doi:10.48550/arXiv.1612.01408") and published paper in Clark (2019) tools:::Rd_expr_doi("doi:10.1007/s13524-019-00785-3").

Arguments

SVDMx functions

qx takes child or child/adult mortality and generates full age schedules of mortality.

Author

Maintainer: Samuel Clark work@samclark.net [copyright holder]