qx: Generate 1qx or 5qx age schedule of mortality from child or child/adult mortality
Description
Generate single-year 1qx or 5-year 5qx age-specific probabilities of dying using the SVD-Comp mortality model indexed by child mortality, 5q0, or child and adult mortality, 5q0 and 45q15.
Usage
qx(
sex,
cm,
smooth = TRUE,
outlogit = FALSE,
out5 = TRUE,
am = NULL,
modsv = 2024
)
Value
Data frame: generated 1qx or 5qx values. Oldest age assumed to be 1.0. Columns labeled with input child mortality values.
Arguments
sex
Character: 'female' or 'male'.
cm
Decimal: the input value(s) for 5q0; either a single value or a vector of values.
smooth
Boolean: use either smooth or raw SVD-derived components. Default is TRUE.
outlogit
Boolean: output either logit-scale or natural-scale nqx values. Default is FALSE. When TRUE oldest age not returned because logit(1) not defined.
out5
Boolean: output either 5-year or 1-year age groups. Default is TRUE.
am
Optional decimal: input value(s) for 45q15; either single value or vector of values. If a vector, must have the same number of elements as cm.
modsv
Optional integer: specifies version of calibration models to use: 2018, 2022, or 2024. Defaults is 2024.